@@ -1,7 +1,6 @@
 use std::slice::Iter;
 
-use crate::comment::Comment;
-use crate::fragment::Fragment;
+use crate::{comment::Comment, fragment::Fragment};
 
 /// A collection of comments from a `CommitMessage`
 #[derive(Debug, PartialEq, Clone)]
@@ -15,8 +14,7 @@ impl Comments {
     /// # Examples
     ///
     /// ```
-    /// use mit_commit::Comment;
-    /// use mit_commit::Comments;
+    /// use mit_commit::{Comment, Comments};
     ///
     /// let trailers = Comments::from(vec![
     ///     Comment::from("# Comment 1"),
@@ -36,6 +34,34 @@ impl Comments {
     }
 }
 
+impl IntoIterator for Comments {
+    type IntoIter = std::vec::IntoIter<Comment>;
+    type Item = Comment;
+
+    /// Iterate over the `Comment` in the `Comments`
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use mit_commit::{Comment, Comments};
+    ///
+    /// let trailers = Comments::from(vec![
+    ///     Comment::from("# Comment 1"),
+    ///     Comment::from("# Comment 2"),
+    ///     Comment::from("# Comment 3"),
+    /// ]);
+    /// let mut iterator = trailers.into_iter();
+    ///
+    /// assert_eq!(iterator.next(), Some(Comment::from("# Comment 1")));
+    /// assert_eq!(iterator.next(), Some(Comment::from("# Comment 2")));
+    /// assert_eq!(iterator.next(), Some(Comment::from("# Comment 3")));
+    /// assert_eq!(iterator.next(), None);
+    /// ```
+    fn into_iter(self) -> Self::IntoIter {
+        self.comments.into_iter()
+    }
+}
+
 impl From<Vec<Comment>> for Comments {
     fn from(comments: Vec<Comment>) -> Self {
         Comments { comments }
@@ -70,20 +96,14 @@ impl From<Vec<Fragment>> for Comments {
 
 #[cfg(test)]
 mod tests {
-    use pretty_assertions::assert_eq;
-
     use indoc::indoc;
 
-    use crate::body::Body;
-    use crate::comment::Comment;
-    use crate::fragment::Fragment;
-
     use super::Comments;
+    use crate::{body::Body, comment::Comment, fragment::Fragment};
 
     #[test]
     fn implements_iterator() {
-        use crate::Comment;
-        use crate::Comments;
+        use crate::{Comment, Comments};
         let trailers = Comments::from(vec![
             Comment::from("# Comment 1"),
             Comment::from("# Comment 2"),
